@@ -1,8 +1,7 @@
 package Tie::Redis::Hash;
 BEGIN {
-  $Tie::Redis::Hash::VERSION = '0.22_1';
+  $Tie::Redis::Hash::VERSION = '0.1';
 }
-# ABSTRACT: Connect a Redis hash to a Perl hash
 
 sub TIEHASH {
   my($class, %args) = @_;
@@ -66,19 +65,28 @@ sub SCALAR {
 1;
 
 
-
 __END__
 =pod
 
 =head1 NAME
 
+Tie::Redis::Hash
+
+=head1 VERSION
+
+version 0.1
+
+=head1 SYNOPSIS
+
+=cut
+
+=head1 NAME
+
 Tie::Redis::Hash - Connect a Redis hash to a Perl hash
 
 =head1 VERSION
 
-version 0.22_1
-
-=head1 SYNOPSIS
+version 0.1
 
 =head1 AUTHOR
 
