@@ -1,8 +1,7 @@
 package Tie::Redis::List;
 BEGIN {
-  $Tie::Redis::List::VERSION = '0.22_1';
+  $Tie::Redis::List::VERSION = '0.1';
 }
-# ABSTRACT: Connect a Redis list to a Perl array
 
 sub TIEARRAY {
   my($class, %args) = @_;
@@ -46,29 +45,6 @@ sub STORE {
   }
 }
 
-sub POP {
-  my($self) = @_;
-  $self->_cmd("rpop");
-}
-
-sub SHIFT {
-  my($self) = @_;
-  $self->_cmd("lpop");
-}
-
-sub UNSHIFT {
-  my($self, $value) = @_;
-  $self->_cmd(lpush => $value);
-}
-
-sub SPLICE {
-  my($self, $offset, $length, @list) = @_;
-
-  my @items = $length == 0 ? () : $self->_cmd(lrange => $offset, $length - 1);
-  $self->_cmd(ltrim => $offset, $offset + $length - 1) if $length > 0;
-  # XXX
-}
-
 sub CLEAR {
   my($self) = @_;
   $self->_cmd("del");
@@ -82,13 +58,23 @@ __END__
 
 =head1 NAME
 
+Tie::Redis::List
+
+=head1 VERSION
+
+version 0.1
+
+=head1 SYNOPSIS
+
+=cut
+
+=head1 NAME
+
 Tie::Redis::List - Connect a Redis list to a Perl array
 
 =head1 VERSION
 
-version 0.22_1
-
-=head1 SYNOPSIS
+version 0.1
 
 =head1 AUTHOR
 
